@@ -1,13 +1,11 @@
-from __future__ import unicode_literals
 import copy
+
 import pytest
 
+from dvc.dependency import DEP_MAP, _get
 from dvc.stage import Stage
-from dvc.dependency import _get, DEP_MAP
-
 from tests.func.test_output import TESTS as OUT_TESTS
 
-
 TESTS = copy.copy(OUT_TESTS)
 TESTS.append(("http://example.com/path/to/file", "http"))
 TESTS.append(("https://example.com/path/to/file", "https"))
@@ -18,5 +16,6 @@ def _get_dep(dvc, path):
 
 
 @pytest.mark.parametrize("url,scheme", TESTS)
-def test_scheme(dvc_repo, url, scheme):
-    assert type(_get_dep(dvc_repo, url)) == DEP_MAP[scheme]
+def test_scheme(dvc, url, scheme):
+    # pylint: disable=unidiomatic-typecheck
+    assert type(_get_dep(dvc, url)) == DEP_MAP[scheme]
