@@ -1,24 +1,18 @@
-import os
-import sys
-
 import pytest
 
+from dvc.output import OUTS_MAP, _get
 from dvc.stage import Stage
-from dvc.output import _get, OUTS_MAP
+from tests import PY39, PYARROW_NOT_AVAILABLE
 
+MARKERS = [
+    pytest.mark.skipif(PY39, reason=PYARROW_NOT_AVAILABLE),
+    pytest.mark.hdfs,
+]
 
 TESTS = [
     ("s3://bucket/path", "s3"),
     ("gs://bucket/path", "gs"),
     ("ssh://example.com:/dir/path", "ssh"),
-    pytest.param(
-        "hdfs://example.com/dir/path",
-        "hdfs",
-        marks=pytest.mark.skipif(
-            sys.version_info[0] == 2 and os.name == "nt",
-            reason="Not supported for python 2 on Windows.",
-        ),
-    ),
     ("path/to/file", "local"),
     ("path\\to\\file", "local"),
     ("file", "local"),
@@ -27,6 +21,8 @@ TESTS = [
     ("../file", "local"),
     ("..\\file", "local"),
     ("unknown://path", "local"),
+    pytest.param("hdfs://example.com/dir/path", "hdfs", marks=MARKERS),
+    pytest.param("hdfs://example.com/dir/path", "hdfs", marks=MARKERS),
 ]
 
 
@@ -35,5 +31,6 @@ def _get_out(dvc, path):
 
 
 @pytest.mark.parametrize("url,scheme", TESTS)
-def test_scheme(dvc_repo, url, scheme):
-    assert type(_get_out(dvc_repo, url)) == OUTS_MAP[scheme]
+def test_scheme(dvc, url, scheme):
+    # pylint: disable=unidiomatic-typecheck
+    assert type(_get_out(dvc, url)) == OUTS_MAP[scheme]
